import {
  UserLayout,
  BasicLayout,
  PageView
} from '@/layouts'

export const asyncRouterMap = [{
  path: '/',
  name: 'index',
  component: BasicLayout,
  meta: {
    title: '首页'
  },
  redirect: '/home',
  children: [{
    path: '/home',
    name: 'home',
    redirect: '/home',
    component: PageView,
    meta: {
      title: '首页',
      icon: 'home'
    },
    hideChildrenInMenu: true,
    children: [{
      path: '/home',
      name: 'home',
      component: () => import(/* webpackChunkName: "home" */ '@/views/Home'),
      meta: {
        title: '首页',
        icon: 'home',
        hidden: true
      }
    },
    {
      path: '/changePwd',
      name: 'changePwd',
      component: () => import(/* webpackChunkName: "home" */ '@/views/user/ChangePwd'),
      meta: {
        title: '修改密码',
        icon: 'home',
        hidden: true
      }
    }
    ]
  },
  {
    path: '/SetmealSales',
    redirect: '/SetmealSales/VerificationRecords',
    name: 'SetmealSales',
    component: PageView,
    meta: {
      title: '套餐销售',
      icon: 'snippets',
      permission: 'M_order_0'
    },
    children: [{
      path: '/SetmealSales/VerificationRecords',
      name: 'VerificationRecords',
      component: () => import('@/views/SetmealSales/VerificationRecords.vue'),
      meta: {
        title: '核销记录',
        icon: 'file-text'
        // permission: 'M_order_list'
      }
    },
    {
      path: '/SetmealSales/BuySetmeal',
      name: 'BuySetmeal',
      component: () => import('@/views/SetmealSales/BuySetmeal.vue'),
      meta: {
        title: '购买套餐',
        icon: 'file-text'
        // permission: 'M_order_list'
      }
    },
    {
      path: '/SetmealSales/PurchasedSetmeal',
      name: 'PurchasedSetmeal',
      component: () => import('@/views/SetmealSales/PurchasedSetmeal.vue'),
      meta: {
        title: '已购套餐',
        icon: 'file-text'
        // permission: 'M_order_list'
      }
    }
    ]
  },
  {
	  path: '/FinancialManagement',
	  name: 'FinancialManagement',
	  component: PageView,
	  meta: { title: '财务管理', icon: 'account-book' },
	  children: [
	    {
	      path: 'PaySettlementRecords/list',
	      name: 'PaySettlementRecords',
	      component: () => import(/* webpackChunkName: "writeOff" */ '@/views/FinancialManagement/PaySettlementRecords.vue'),
	      meta: { title: '应付结算记录', icon: 'form' }
	    }
	  ]
  },
  {
    path: '/auth',
    redirect: '/auth/userList',
    component: PageView,
    meta: {
      title: '运营平台权限管理',
      icon: 'apartment',
      permission: 'M_yyAuth_0'
    },
    children: [
      {
        path: '/auth/userList',
        name: 'powerUserList',
        component: () => import(/* webpackChunkName: "auth" */ '@/views/power/user/userList.vue'),
        meta: {
          title: '用户管理',
          icon: 'user',
          permission: 'M_auth_yyUser'
        }
      },
      {
        path: '/auth/roleList',
        name: 'powerRoleList',
        component: () => import(/* webpackChunkName: "auth" */ '@/views/power/role/roleList.vue'),
        meta: {
          title: '角色管理',
          icon: 'solution',
          permission: 'M_auth_yyRole'
        }
      }
    ]
  },
  {
    path: '/setting',
    redirect: '/setting/userList',
    component: PageView,
    meta: {
      title: '系统设置',
      icon: 'setting',
      permission: 'M_setting_0'
    },
    children: [{
      path: '/setting/dataDictionary',
      name: 'powerDD',
      component: () => import(/* webpackChunkName: "setting" */
        '@/views/power/dataDictionary/dataDictionary.vue'),
      meta: {
        title: '数据字典管理',
        icon: 'database',
        permission: 'M_sys_dataDictionary'
      }
    }
      // 暂时屏蔽,后期可能需要
      // {
      //   path: '/setting/register',
      //   name: 'powerRegister',
      //   component: () => import( /* webpackChunkName: "setting" */ '@/views/power/register/register.vue'),
      //   meta: {
      //     title: '参数管理',
      //     icon: 'key'
      //     // permission: 'M_sys_register'
      //   }
      // },
      // 暂时屏蔽,后期可能需要
      // {
      //   path: '/setting/jobs',
      //   name: 'powerJobs',
      //   component: () => import( /* webpackChunkName: "setting" */ '@/views/power/job/jobs.vue'),
      //   meta: {
      //     title: '定时器',
      //     icon: 'alert'
      //     // permission: 'M_sys_job'
      //   }
      // }
    ]
  }
  ]
},
{
  path: '*',
  redirect: '/404',
  hidden: true
}
]

/**
 * 基础路由
 * @type { *[] }
 */
export const constantRouterMap = [{
  path: '/user',
  component: UserLayout,
  redirect: '/user/login',
  hidden: true,
  children: [{
    path: 'login',
    name: 'login',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Login')
  },
  {
    path: 'register',
    name: 'register',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/Register')
  },
  {
    path: 'register-result',
    name: 'registerResult',
    component: () => import(/* webpackChunkName: "user" */ '@/views/user/RegisterResult')
  },
  {
    path: 'recover',
    name: 'recover',
    component: undefined
  }
  ]
},
{
  path: '/404',
  component: () => import(/* webpackChunkName: "fail" */ '@/views/exception/404')
}

]
